package gov.nih.nlm.nls.lexCheck.Api;
import java.util.*;
import java.io.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.Gram.*;
/*****************************************************************************
* This class provides an Java Api for reading lexical records in text format 
* and send agreements to output.  The input can be a file or a string.
*
* <p><b>History:</b>
* <ul>
* <li>SCR-51, chlu, 12-10-15, build with java 1.8
* </ul>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class ToAgreementsApi
{
    // public method
    /**
    * A method to generate agreements from a file contains
    * lexical records in text format.
    *
    * @param inFile  the file name of the lexical records in text format
    *
    * @return  a vector of elements of Agreements
    */
    public static Vector<Agreement> GetAgreementsFromTextFile(String inFile)
    {
        CheckSt st = new CheckSt();     // upper level  Check state
        CheckSt catSt = new CheckSt(CheckSt.CHECK_CAT_ENTRY);
            // Category dependant Check state
        LineObject lineObject = new LineObject();
        Vector<Agreement> agreements = new Vector<Agreement>();
        try
        {
            BufferedReader inReader = new BufferedReader(new InputStreamReader(
                new FileInputStream(inFile), "UTF-8"));
            while(lineObject != null)
            {
                // check if read in the next line
                if(lineObject.IsGoToNext() == true)
                {
                    lineObject.SetLine(inReader.readLine());
                    lineObject.IncreaseLineNum();
                }
                if(lineObject.GetLine() == null)
                {
                    break;
                }
                // go through each line
                // check input for quitiing
                boolean flag = 
                    CheckGrammer.Check(lineObject, true, st, catSt, false);
                // generate inflVars when processing one lexical record 
                if((st.GetCurState() == CheckSt.CHECK_BASE)
                && (flag == true))
                {
                    InflVarsAndAgreements agrs = 
                        new InflVarsAndAgreements(CheckGrammer.GetLexRecord());
                    agreements.addAll(agrs.GetAgreementValues());
                }
            }
            inReader.close();
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }
        return agreements;
    }
    /**
    * A unit test driver for ToXmlApi.
	*
	* @param  args  input arguments
    */
    public static void main(String[] args)
    {
        String inFile = "molt"; 
        // Go through LexCheck
        Vector<Agreement> temp 
            = ToAgreementsApi.GetAgreementsFromTextFile(inFile);
    }
}
