package gov.nih.nlm.nls.lexCheck.Cat.Adj;
import java.util.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.CkLib.*;
/*****************************************************************************
* This class checks allowable filler for syntactical category of adjective.
*
* <p><b>History:</b>
*
* @author NLM LVG Development Team
*
* @version    V-2016
****************************************************************************/
public class CheckAdj
{
    // public method
    /**
    * Check a line to see if it is a legel filler.
    *
    * @param   lineObject  the java object of a input line
    * @param   printFlag   the flag for print out check result
    * @param   catSt       the state of category
    * @param   lexObj   the current object of lexical record
    * @param   debugFlag   the flag for print out debug information
    *
    * @return  true or false for legal and illegal filler.
    */
    public static boolean Check(LineObject lineObject, boolean printFlag,
        CheckSt catSt, LexRecord lexObj, boolean debugFlag)
    {
        boolean flag = true;
        int curSt = catSt.GetCurState();
        // reset the state if it is first time
        if(curSt == CheckSt.CHECK_CAT_ENTRY)
        {
            curSt = CheckSt.CHECK_ADJ_VARIANTS;
            catSt.SetCurState(curSt);
        }
        switch(curSt)
        {
            case CheckSt.CHECK_ADJ_VARIANTS:
                flag = CheckCode.Check(lineObject, printFlag, catSt, lexObj,
                    checkVariants_, new UpdateAdjVariants(), 
                    CheckCode.FQ_ONE_MANY, true);
                PrintStep(CheckSt.CHECK_ADJ_VARIANTS, debugFlag, 
                    lineObject.GetLine());
                break;
            case CheckSt.CHECK_ADJ_POSITION:
                flag = CheckCode.Check(lineObject, printFlag, catSt, lexObj,
                    checkPosition_, new UpdateAdjPosition(), 
                    CheckCode.FQ_ONE_MANY, true);
                PrintStep(CheckSt.CHECK_ADJ_POSITION, debugFlag, 
                    lineObject.GetLine());
                break;
            case CheckSt.CHECK_ADJ_COMPL:
                flag = CheckCode.Check(lineObject, printFlag, catSt, lexObj,
                    checkCompl_, new UpdateAdjCompl(), 
                    CheckCode.FQ_ZERO_MANY, true);
                PrintStep(CheckSt.CHECK_ADJ_COMPL, debugFlag, 
                    lineObject.GetLine());
                break;
            case CheckSt.CHECK_ADJ_STATIVE:
                flag = CheckCode.Check(lineObject, printFlag, catSt, lexObj,
                    checkStative_, new UpdateAdjStative(), 
                    CheckCode.FQ_ZERO_ONE_WHOLE_LINE, false);
                PrintStep(CheckSt.CHECK_ADJ_STATIVE, debugFlag, 
                    lineObject.GetLine());
                break;
            case CheckSt.CHECK_ADJ_NOMINALIZATION:
                flag = CheckCode.Check(lineObject, printFlag, catSt, lexObj,
                    checkNominalization_, new UpdateAdjNominalization(), 
                    CheckCode.FQ_ZERO_MANY, true);
                PrintStep(CheckSt.CHECK_ADJ_NOMINALIZATION, debugFlag, 
                    lineObject.GetLine());
                break;
        }
        return flag;
    }
    // private method
    private static void PrintStep(int state, boolean debugFlag, String line)
    {
        if(debugFlag == true)
        {
            switch(state)
            {
                case CheckSt.CHECK_ADJ_VARIANTS:
                    System.out.println("-- Checked Adj Variants: '" + line 
                        + "'");
                    break;
                case CheckSt.CHECK_ADJ_POSITION:
                    System.out.println("-- Checked Adj Position: '" + line 
                        + "'");
                    break;
                case CheckSt.CHECK_ADJ_COMPL:
                    System.out.println("-- Checked Adj Complement: '" 
                        + line + "'");
                    break;
                case CheckSt.CHECK_ADJ_STATIVE:
                    System.out.println("-- Checked Adj Stative: '" + line 
                        + "'");
                    break;
                case CheckSt.CHECK_ADJ_NOMINALIZATION:
                    System.out.println("-- Checked Adj Nominalization: '" + line
                        + "'");
                    break;
            }
        }
    }
    // data member
    private static CheckObject checkVariants_ = null;
    private static HashSet<String> variantsNextStartStrs_ 
        = new HashSet<String>(9);
    private static CheckObject checkPosition_ = null;
    private static HashSet<String> positionNextStartStrs_ 
        = new HashSet<String>(8);
    private static CheckObject checkCompl_ = null;
    private static HashSet<String> complNextStartStrs_ 
        = new HashSet<String>(7);
    private static CheckObject checkStative_ = null;
    private static HashSet<String> stativeNextStartStrs_ 
        = new HashSet<String>(6);
    private static CheckObject checkNominalization_ = null;
    private static HashSet<String> nominalizationNextStartStrs_ 
        = new HashSet<String>(5);
    static
    {
        // slot variants=
        variantsNextStartStrs_.add("\tposition=");
        variantsNextStartStrs_.add("\tcompl=");
        variantsNextStartStrs_.add("\tstative");
        variantsNextStartStrs_.add("\tnominalization=");
        variantsNextStartStrs_.add("\tacronym_of=");
        variantsNextStartStrs_.add("\tabbreviation_of=");
        variantsNextStartStrs_.add("annotation=");
        variantsNextStartStrs_.add("signature=");
        variantsNextStartStrs_.add("}");
        checkVariants_ = new CheckObject("\tvariants=", 
            ErrMsg.ADJ_VAR_SLOT_ERR, ErrMsg.ADJ_VAR_FILLER_ERR, 
            CheckSt.CHECK_ADJ_POSITION, variantsNextStartStrs_,
            new CheckFormatAdjVariants());
        // slot position=
        positionNextStartStrs_.add("\tcompl=");
        positionNextStartStrs_.add("\tstative");
        positionNextStartStrs_.add("\tnominalization=");
        positionNextStartStrs_.add("\tacronym_of=");
        positionNextStartStrs_.add("\tabbreviation_of=");
        positionNextStartStrs_.add("annotation=");
        positionNextStartStrs_.add("signature=");
        positionNextStartStrs_.add("}");
        checkPosition_ = new CheckObject("\tposition=", 
            ErrMsg.ADJ_POSITION_SLOT_ERR, ErrMsg.ADJ_POSITION_FILLER_ERR,
            CheckSt.CHECK_ADJ_COMPL, positionNextStartStrs_, 
            new CheckFormatAdjPosition());
        // slot compl=
        complNextStartStrs_.add("\tstative");
        complNextStartStrs_.add("\tnominalization=");
        complNextStartStrs_.add("\tacronym_of=");
        complNextStartStrs_.add("\tabbreviation_of=");
        complNextStartStrs_.add("annotation=");
        complNextStartStrs_.add("signature=");
        complNextStartStrs_.add("}");
        checkCompl_ = new CheckObject("\tcompl=", 
            ErrMsg.ADJ_COMPL_SLOT_ERR, ErrMsg.ADJ_COMPL_FILLER_ERR,
            CheckSt.CHECK_ADJ_STATIVE, complNextStartStrs_, 
            new CheckFormatAdjCompl());
        // slot stative
        stativeNextStartStrs_.add("\tnominalization=");
        stativeNextStartStrs_.add("\tacronym_of=");
        stativeNextStartStrs_.add("\tabbreviation_of=");
        stativeNextStartStrs_.add("annotation=");
        stativeNextStartStrs_.add("signature=");
        stativeNextStartStrs_.add("}");
        checkStative_ = new CheckObject("\tstative", 
            ErrMsg.ADJ_STATIVE_SLOT_ERR, ErrMsg.NONE,
            CheckSt.CHECK_ADJ_NOMINALIZATION, stativeNextStartStrs_, 
            null);
        nominalizationNextStartStrs_.add("\tacronym_of=");
        nominalizationNextStartStrs_.add("\tabbreviation_of=");
        nominalizationNextStartStrs_.add("annotation=");
        nominalizationNextStartStrs_.add("signature=");
        nominalizationNextStartStrs_.add("}");
        checkNominalization_ = new CheckObject("\tnominalization=", 
            ErrMsg.ADJ_NOMINALIZATION_SLOT_ERR, 
            ErrMsg.ADJ_NOMINALIZATION_FILLER_ERR, 
            CheckSt.CHECK_ACRONYM, nominalizationNextStartStrs_, 
            new CheckFormatAdjNominalization());
    }
}
