package gov.nih.nlm.nls.lexCheck.Cat.Auxi;
import java.util.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.CkLib.*;
/*****************************************************************************
* This class checks filler for syntactical category of Auxilary.
*
* <p><b>History:</b>
*
* @author NLM LVG Development Team
*
* @version    V-2016
****************************************************************************/
public class CheckAux
{
    // public method
    /**
    * Check a line to see if it is a legel filler.
    *
    * @param   lineObject  the java object of a input line
    * @param   printFlag   the flag for print out check result
    * @param   catSt       the state of category
    * @param   lexObj   the current object of lexical record
    * @param   debugFlag   the flag for print out debug information
    *
    * @return  true or false for legal and illegal filler.
    */
    public static boolean Check(LineObject lineObject, boolean printFlag,
        CheckSt catSt, LexRecord lexObj, boolean debugFlag)
    {
        boolean flag = true;
        int curSt = catSt.GetCurState();
        // reset the state if it is first time
        if(curSt == CheckSt.CHECK_CAT_ENTRY)
        {
            curSt = CheckSt.CHECK_AUX_VARIANT;
            catSt.SetCurState(curSt);
        }
        switch(curSt)
        {
            case CheckSt.CHECK_AUX_VARIANT:
                flag = CheckCode.Check(lineObject, printFlag, catSt, lexObj,
                    checkVariant_, new UpdateAuxVariant(), 
                    CheckCode.FQ_ONE_MANY, true);
                PrintStep(CheckSt.CHECK_AUX_VARIANT, debugFlag, 
                    lineObject.GetLine());
                break;
        }
        return flag;
    }
    // private method
    private static void PrintStep(int state, boolean debugFlag, String line)
    {
        if(debugFlag == true)
        {
            switch(state)
            {
                case CheckSt.CHECK_AUX_VARIANT:
                    System.out.println("-- Checked Aux Variant: '" + line 
                        + "'");
                    break;
            }
        }
    }
    // data member
    private static CheckObject checkVariant_ = null;
    private static HashSet<String> variantNextStartStrs_ 
        = new HashSet<String>(5);
    static
    {
        // slot variant=
        variantNextStartStrs_.add("\tacronym_of=");
        variantNextStartStrs_.add("\tabbreviation_of=");
        variantNextStartStrs_.add("annotation=");
        variantNextStartStrs_.add("signature=");
        variantNextStartStrs_.add("}");
        checkVariant_ = new CheckObject("\tvariant=", ErrMsg.AUX_VAR_SLOT_ERR,
            ErrMsg.AUX_VAR_FILLER_ERR, CheckSt.CHECK_ACRONYM,
            variantNextStartStrs_, new CheckFormatAuxVariant());
    }
}
