package gov.nih.nlm.nls.lexCheck.Cat.Det;
import java.util.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.CkLib.*;
/*****************************************************************************
* This class checks filler type for syntactical category of determiners.
*
* <p><b>History:</b>
*
* @author NLM LVG Development Team
*
* @version    V-2016
****************************************************************************/
public class CheckDet
{
    // public method
    /**
    * Check a line to see if it is a legel filler.
    *
    * @param   lineObject  the java object of a input line
    * @param   printFlag   the flag for print out check result
    * @param   catSt       the state of category
    * @param   lexObj   the current object of lexical record
    * @param   debugFlag   the flag for print out debug information
    *
    * @return  true or false for legal and illegal filler.
    */
    public static boolean Check(LineObject lineObject, boolean printFlag,
        CheckSt catSt, LexRecord lexObj, boolean debugFlag)
    {
        boolean flag = true;
        int curSt = catSt.GetCurState();
        // reset the state if it is first time
        if(curSt == CheckSt.CHECK_CAT_ENTRY)
        {
            curSt = CheckSt.CHECK_DET_VARIANTS;
            catSt.SetCurState(curSt);
        }
        switch(curSt)
        {
            case CheckSt.CHECK_DET_VARIANTS:
                flag = CheckCode.Check(lineObject, printFlag, catSt, lexObj,
                    checkVariants_, new UpdateDetVariants(), CheckCode.FQ_ONE,
                    true);
                PrintStep(CheckSt.CHECK_DET_VARIANTS, debugFlag, 
                    lineObject.GetLine());
                break;
            case CheckSt.CHECK_DET_INTERROGATIVE:
                flag = CheckCode.Check(lineObject, printFlag, catSt, lexObj,
                    checkInterrogative_, new UpdateDetInterrogative(), 
                    CheckCode.FQ_ZERO_ONE_WHOLE_LINE, false);
                PrintStep(CheckSt.CHECK_DET_INTERROGATIVE, debugFlag, 
                    lineObject.GetLine());
                break;
            case CheckSt.CHECK_DET_DEMONSTRATIVE:
                flag = CheckCode.Check(lineObject, printFlag, catSt, lexObj,
                    checkDemonstrative_, new UpdateDetDemonstrative(), 
                    CheckCode.FQ_ZERO_ONE_WHOLE_LINE, false);
                PrintStep(CheckSt.CHECK_DET_INTERROGATIVE, debugFlag, 
                    lineObject.GetLine());
                break;
        }
        return flag;
    }
    // private method
    private static void PrintStep(int state, boolean debugFlag, String line)
    {
        if(debugFlag == true)
        {
            switch(state)
            {
                case CheckSt.CHECK_DET_VARIANTS:
                    System.out.println("-- Checked Det Variants: '" + line 
                        + "'");
                    break;
                case CheckSt.CHECK_DET_INTERROGATIVE:
                    System.out.println("-- Checked Det Interrogative: '" + line 
                        + "'");
                    break;
                case CheckSt.CHECK_DET_DEMONSTRATIVE:
                    System.out.println("-- Checked Det Demonstrative: '" + line 
                        + "'");
                break;
            }
        }
    }
    // data member
    private static CheckObject checkVariants_ = null;
    private static CheckObject checkInterrogative_ = null;
    private static HashSet<String> interrogativeNextStartStrs_ 
        = new HashSet<String>(6);
    private static CheckObject checkDemonstrative_ = null;
    private static HashSet<String> demonstrativeNextStartStrs_ 
        = new HashSet<String>(5);
    static
    {
        // slot variants=
        checkVariants_ = new CheckObject("\tvariants=", ErrMsg.DET_VAR_SLOT_ERR,
            ErrMsg.DET_VAR_FILLER_ERR, CheckSt.CHECK_DET_INTERROGATIVE,
            null, new CheckFormatDetVariants());
        // slot interrogative
        interrogativeNextStartStrs_.add("\tdemonstrative");
        interrogativeNextStartStrs_.add("\tacronym_of=");
        interrogativeNextStartStrs_.add("\tabbreviation_of=");
        interrogativeNextStartStrs_.add("annotation=");
        interrogativeNextStartStrs_.add("signature=");
        interrogativeNextStartStrs_.add("}");
        checkInterrogative_ = new CheckObject("\tinterrogative", 
            ErrMsg.DET_INTERROGATIVE_SLOT_ERR, ErrMsg.NONE,
            CheckSt.CHECK_DET_DEMONSTRATIVE, interrogativeNextStartStrs_, null);
        // slot demonstrative, next catState is CHECK_CAT_ENTRY,
        demonstrativeNextStartStrs_.add("\tacronym_of=");
        demonstrativeNextStartStrs_.add("\tabbreviation_of=");
        demonstrativeNextStartStrs_.add("annotation=");
        demonstrativeNextStartStrs_.add("signature=");
        demonstrativeNextStartStrs_.add("}");
        checkDemonstrative_ = new CheckObject("\tdemonstrative", 
            ErrMsg.DET_DEMONSTRATIVE_SLOT_ERR, ErrMsg.NONE,
            CheckSt.CHECK_ACRONYM, demonstrativeNextStartStrs_, null);
    }
}
