package gov.nih.nlm.nls.lexCheck.Cat.Verb;
import java.util.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.Compl.*;
/*****************************************************************************
* This class checks format of complex transitive complements for verb.
*
* <p><b>History:</b>
*
* @author NLM LVG Development Team
*
* @version    V-2016
****************************************************************************/
public class CheckFormatVerbCplxtran implements CheckFormat
{
    // public method
    /**
    * Check a line to see if it is a legal format of complex transitive 
    * complements of verb.
    *
    * @param   inCode   the filler of verb complex transitive complements.
    *
    * @return  true or false for legal and illegal filler.
    */
    public boolean IsLegalFormat(String inCode)
    {
        boolean flag = false;
        int partIndex = inCode.indexOf(";part(");
        int passiveIndex = inCode.indexOf(";nopass");
        String filler = null;
        String particle = null;
        boolean passive = false;
        // get filler
        if(partIndex != -1)
        {
            filler = inCode.substring(0, partIndex);
            // Get particle code
            if(passiveIndex != -1)
            {
                particle = inCode.substring(partIndex, passiveIndex);
            }
            else
            {
                particle = inCode.substring(partIndex);
            }
        }
        else
        {
            if(passiveIndex != -1)
            {
                filler = inCode.substring(0, passiveIndex);
            }
            else
            {
                filler = inCode;
            }
           }
        // check filler & particle code
        if(particle != null)
        {
            flag = CheckCplxtranFiller(filler) 
                && CheckParticle.IsLegal(particle);
        }
        else
        {
            flag = CheckCplxtranFiller(filler);
        }
        return flag;
    }
    // private method
    private boolean CheckCplxtranFiller(String filler)
    {
        boolean flag = false;
        String filler1 = new String();
        String filler2 = new String();
        if(filler.startsWith("pphr(") == true)
        {
            int index = filler.indexOf("),");
            filler1 = filler.substring(0, index+1);
            filler2 = filler.substring(index+2);
        }
        else
        {
            int index = filler.indexOf(",");
            filler1 = filler.substring(0, index);
            filler2 = filler.substring(index+1);
        }
        flag = CheckFiller1(filler1) && CheckFiller2(filler2);
        return flag;
    }
    private boolean CheckFiller1(String filler)
    {
        boolean flag = false;
        if(filler1_.contains(filler) == true)
        {
            flag = true;
        }
        else if(filler.startsWith("fincomp(") == true)
        {
            flag = CheckFinComp.IsLegal(filler);
        }
        else if(filler.startsWith("ingcomp:") == true)
        {
            flag = CheckIngComp.IsLegal(filler);
        }
        else if(filler.startsWith("pphr(") == true)
        {
            flag = CheckPphr.IsLegal(filler);
        }
        return flag;
    }
    private boolean CheckFiller2(String filler)
    {
        boolean flag = false;
        if(filler2_.contains(filler) == true)
        {
            flag = true;
        }
        else if(filler.startsWith("ascomp:") == true)
        {
            flag = CheckAsComp.IsLegal(filler);
        }
        else if(filler.startsWith("binfcomp:") == true)
        {
            flag = CheckBinfComp.IsLegal(filler);
        }
        else if(filler.startsWith("edcomp:") == true)
        {
            flag = CheckEdComp.IsLegal(filler);
        }
        else if(filler.startsWith("infcomp:") == true)
        {
            flag = CheckInfComp.IsLegal(filler);
        }
        else if(filler.startsWith("ingcomp:") == true)
        {
            flag = CheckIngComp.IsLegal(filler);
        }
        else if(filler.startsWith("pphr(") == true)
        {
            flag = CheckPphr.IsLegal(filler);
        }
        return flag;
    }
    // data member
    private final static int LEGAL_FILLER1_NUM = 1;
    private static HashSet<String> filler1_ 
        = new HashSet<String>(LEGAL_FILLER1_NUM);
    private final static int LEGAL_FILLER2_NUM = 2;
    private static HashSet<String> filler2_ 
        = new HashSet<String>(LEGAL_FILLER2_NUM);
    static
    {
        filler1_.add("np");
        filler2_.add("adj");
        filler2_.add("advbl");
        filler2_.add("np");
    }
}
