package gov.nih.nlm.nls.lexCheck.CheckCont;
import gov.nih.nlm.nls.lvg.Util.UnicodeUtil;
import java.util.*; 
/*****************************************************************************
* This program provide a comparator class for base forms.
* The algorithm of this sorting order are:
* <ul>
* <li>Pure ASCII first
* <li>No punctuation first
* <li>Shorter length first
* <li>By string character value (alphabetic order)
* </ul>
* The first one in the sorted list is assigned as citation form.
* The spelling variants are sorted in the above sorting order:
*
* <p><b>History:</b>
*
* @author NLM NLS Development Team
*
* @version    V-2016
****************************************************************************/
public class BaseComparator<T> implements Comparator<T>
{
    // public methods
    /**
    * Compare two objects by base order
    *
    * @param   o1  the first object to be compared
    * @param   o2  the second object to be compared
    *
    * @return  negative integer, zero, or a positive integer as the first 
    *          argument is less than, equal to, or greater than the second.
    */
    public int compare(T o1, T o2)
    {
        // pure ASCII first
        boolean asciiFlag1 = UnicodeUtil.IsAsciiStr((String) o1);
        boolean asciiFlag2 = UnicodeUtil.IsAsciiStr((String) o2);
        if(asciiFlag1 != asciiFlag2)
        {
            if(asciiFlag1 == true)
            {
                return -1;
            }
            else if(asciiFlag2 == true)
            {
                return 1;
            }
        }
        
        // no punctuation first
        boolean puncFlag1 = HasNoPunctuation((String) o1);
        boolean puncFlag2 = HasNoPunctuation((String) o2);
        if(puncFlag1 != puncFlag2)
        {
            if(puncFlag1 == true)
            {
                return -1;
            }
            else if(puncFlag2 == true)
            {
                return 1;
            }
        }
        // shortest first
        String str1 = (String) o1;
        String str2 = (String) o2;
        int length1 = str1.length();
        int length2 = str2.length();
        if(length1 != length2)
        {
            return (length1 - length2);
        }
        
        // case sensititve: compare by value
        return str1.compareTo(str2);
    }
    
    /**
    * Test driver for this class.
    * 
    * @param    args    arguments
    */
    public static void main(String[] args)
    {
        Vector<String> baseStrs = new Vector<String>();
        baseStrs.add("M-bcr");
        baseStrs.add("mbcr");
        baseStrs.add("MBCR");
        baseStrs.add("Mbcr");
        baseStrs.add("M-BCR");
        baseStrs.add("M-BĆR");
        baseStrs.add("Mbćr");
        baseStrs.add("Amœba");
        baseStrs.add("Amoeba");
        baseStrs.add("résumé");
        baseStrs.add("resume");
        baseStrs.add("colour");
        baseStrs.add("color");
        baseStrs.add("retroceecal");
        baseStrs.add("retrocaecal");
        baseStrs.add("retrocecal");
        baseStrs.add("reo virus");
        baseStrs.add("reovirus");
        PrintList(baseStrs);
        // sort it
        BaseComparator<String> bc = new BaseComparator<String>();
        Collections.sort(baseStrs, bc);
        PrintList(baseStrs);
    }
    // private methods
    private static void PrintList(Vector<String> inList)
    {
        System.out.println("--------------------------------");
        for(String inStr:inList)
        {
            System.out.println(inStr);
        }
    }
    // check if a word has no punctuation
    private static boolean HasNoPunctuation(String inWord)
    {
        boolean noPunctuation = true;
        for(int i = 0; i < inWord.length(); i++)
        {
            if(IsPunctuationChar(inWord.charAt(i)) == true)
            {
                noPunctuation = false;
                break;
            }
        }
        return noPunctuation;
    }
    // check if a chracter a punctuation
    private static boolean IsPunctuationChar(char inChar)
    {
        boolean isPunctuation = false;
        int type = Character.getType(inChar);
        // check if the input is a punctuation
        if((type == Character.DASH_PUNCTUATION)         // -
        || (type == Character.START_PUNCTUATION)        // ( { [
        || (type == Character.END_PUNCTUATION)          // ) } ]
        || (type == Character.CONNECTOR_PUNCTUATION)    // _
        || (type == Character.OTHER_PUNCTUATION)        // !@#%&*\:;"',.?/ 
        || (type == Character.MATH_SYMBOL)              // ~ + = | < >
        || (type == Character.CURRENCY_SYMBOL)          // $
        || (type == Character.MODIFIER_SYMBOL))         // ` ^
        {
            isPunctuation = true;
        }
        return isPunctuation;
    }
    // data members
}
