package gov.nih.nlm.nls.lexCheck.CheckCont;
import java.util.*;
import gov.nih.nlm.nls.lvg.Util.UnicodeUtil;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.Api.*;
/*****************************************************************************
* This class provides a Java class library of checking the content of a 
* lexRecord.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class CheckContent
{
    // private constructor
    private CheckContent()
    {
    }
    // check extra space, this should be checked in LexBuild
    public static boolean CheckSpacesForItem(LexRecord lexRecord,
        int contentType)
    {
        boolean validFlag = true;
        String inItem = LexRecordUtil.GetItemFromLexRecord(lexRecord, 
            contentType);
        String newInItem = StringTrim(inItem);
        if(newInItem.equals(inItem) == false)
        {
            validFlag = false;
            ErrMsgUtilLexRecord.AddContentErrMsg(contentType, 
                ErrMsgUtilLexRecord.ERR_SPACES, inItem, lexRecord);
            // fix record
            LexRecordUtil.SetItemInLexRecord(lexRecord, contentType, newInItem);
        }
        return validFlag;
    }
    
    // check extra space, this should be checked in LexBuild
    public static boolean CheckSpacesForList(LexRecord lexRecord, 
        int contentType)
    {
        boolean validFlag = true;
        // get the working list
        Vector<String> inList 
            = LexRecordUtil.GetListFromLexRecord(lexRecord, contentType);
        for(int i = 0; i < inList.size(); i++)
        {
            String inItem = inList.elementAt(i);
            String newInItem = StringTrim(inItem);
            if(newInItem.equals(inItem) == false)
            {
                validFlag = false && validFlag;
                ErrMsgUtilLexRecord.AddContentErrMsg(contentType, 
                    ErrMsgUtilLexRecord.ERR_SPACES, inItem, lexRecord);
                
                // fix record
                LexRecordUtil.SetItemInListInLexRecordAt(lexRecord,
                    contentType, newInItem, i);
            }
        }
        return validFlag;
    }
    // trim extra space at the beginning, end and between
    private static String StringTrim(String inStr)
    {
        StringTokenizer buf = new StringTokenizer(inStr, " \t");
        String outStr = new String();
        while(buf.hasMoreTokens())
        {
            outStr += buf.nextToken() + " ";
        }
        return outStr.trim();
    }
    
    // check for any duplicated inItem in the inIterms
    // used in duplicated acronyms, abbreviations, nominalizations
    public static boolean CheckDuplicatesForList(LexRecord lexRecord, 
        int contentType)
    {
        boolean validFlag = true;
        // get the working list
        Vector<String> inList 
            = LexRecordUtil.GetListFromLexRecord(lexRecord, contentType);
        Vector<String> uList = new Vector<String>();    
        // go through each item in the lists
        for(int i = 0; i < inList.size(); i++)
        {
            String inItem = inList.elementAt(i);
            // duplicate item
            if(uList.contains(inItem) == true)
            {
                validFlag = false && validFlag;
                ErrMsgUtilLexRecord.AddContentErrMsg(contentType, 
                    ErrMsgUtilLexRecord.ERR_DUPLICATE, inItem, lexRecord);
            }
            else    // add to unique list
            {
                uList.addElement(inItem);
            }
        }
        // fix
        if(validFlag == false)
        {
            LexRecordUtil.SetListInLexRecord(lexRecord, contentType, uList);
        }
        return validFlag;
    }
    // check double pipe with empty data for nom, acr, abb
    public static boolean CheckDoublePipesForList(LexRecord lexRecord, 
        int contentType)
    {
        boolean validFlag = true;
        // get the working list
        Vector<String> inList 
            = LexRecordUtil.GetListFromLexRecord(lexRecord, contentType);
        for(String inItem:inList)
        {
            if(inItem.indexOf("||") >= 0)
            {
                ErrMsgUtilLexRecord.AddContentErrMsg(contentType, 
                    ErrMsgUtilLexRecord.ERR_DOUBLE_PIPES, inItem, lexRecord);
                validFlag = false;
            }
        }
        return validFlag;
    }
    // data member
    /** types: non-Ascii, punctuation */
    public final static int STR_ASCII_NO_PUNC = 0; 
    public final static int STR_ASCII_PUNC = 1; 
    public final static int STR_NON_ASCII_NO_PUNC = 2; 
    public final static int STR_NON_ASCII_PUNC = 3; 
}
