package gov.nih.nlm.nls.lexCheck.CheckCont;
import java.util.*;
import gov.nih.nlm.nls.lvg.Util.UnicodeUtil;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.Api.*;
/*****************************************************************************
* This class provides a Java class to check the Entry of a lexRecord.
* This class is a library class.
* <ul>
* <li>For noun, check if a base has legal Greco-Latin ending for glreg or group(glreg)
* <li>For verb and adj, check if base has correct ending for regd
* </ul>
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class CheckEntry
{
    // private constructor
    private CheckEntry()
    {
    }
    // public methods
    // check if regd variant has right ending (vowel+ consonant)
    public static boolean CheckRegd(LexRecord lexRecord, String inBase,
        int contentType)
    {
        boolean validFlag = true;
        String cat = lexRecord.GetCategory();
        Vector<String> variants = new Vector<String>();
        if(cat.equals(LexRecordUtil.GetCategory(LexRecordUtil.CAT_VERB)))
        {
            variants = lexRecord.GetCatEntry().GetVerbEntry().GetVariants();
        }
        else if(cat.equals(LexRecordUtil.GetCategory(LexRecordUtil.CAT_ADJ)))
        {
            variants = lexRecord.GetCatEntry().GetAdjEntry().GetVariants();
        }
        // check regd ending if verb or adj
        if(variants.size() > 0)
        {
            boolean hasRegd = false;
            // go through all variants
            for(int i = 0; i < variants.size(); i++)
            {
                String variant = variants.elementAt(i);
                if(variant.equals("regd") == true)
                {
                    hasRegd = true;
                    break;
                }
            }
            // check ending of inBase if regd (must be vowel + consonant)
            if(hasRegd == true)
            {
                char lastChar = InflVarsAndAgreements.GetLastChar(inBase);
                char last2Char = InflVarsAndAgreements.GetLast2Char(inBase);
                String lastCharStr = new Character(lastChar).toString();
                String last2CharStr = new Character(last2Char).toString();
                
                // check if the base form ends with VC
                if((InflVarsAndAgreements.consonants_.contains(lastCharStr) == false)
                || (InflVarsAndAgreements.vowels_.contains(last2CharStr) == false))
                {
                    validFlag = false;
                }
            }
            // errMsg
            if(validFlag == false)
            {
                ErrMsgUtilLexRecord.AddContentErrMsg(contentType, 
                    ErrMsgUtilLexRecord.ERR_REGD_ENDING, inBase, lexRecord);
            }
        }
        
        return validFlag;
    }
    // check if Greco-Latin varaint has right ending
    public static boolean CheckGlreg(LexRecord lexRecord, String inBase,
        int contentType)
    {
        boolean validFlag = true;
        String cat = lexRecord.GetCategory();
        if(cat.equals(LexRecordUtil.GetCategory(LexRecordUtil.CAT_NOUN)))
        {
            Vector<String> variants 
                = lexRecord.GetCatEntry().GetNounEntry().GetVariants();
            // go through all variants
            boolean hasGlreg = false; 
            for(int i = 0; i < variants.size(); i++)
            {
                String variant = variants.elementAt(i);
                if((variant.equals("glreg"))
                || (variant.equals("group(glreg)")))
                {
                    hasGlreg = true;
                    break;
                }
            }
            // check ending of inBase if Greco-Latin
            if(hasGlreg == true)
            {
                validFlag = false;
                for(int j = 0; j < glregEnds_.size(); j++)
                {
                    String ending = glregEnds_.elementAt(j);
                    if(inBase.endsWith(ending) == true)
                    {
                        validFlag = true;
                        break;
                    }
                }
            }
            // errMsg
            if(validFlag == false)
            {
                ErrMsgUtilLexRecord.AddContentErrMsg(contentType, 
                    ErrMsgUtilLexRecord.ERR_GLREG_ENDING, inBase, lexRecord);
            }
        }
        return validFlag;
    }
    // data member
    // the ending chars of Greco-Latin
    private static Vector<String> glregEnds_ = new Vector<String>();
    static
    {
        glregEnds_.addElement("us");
        glregEnds_.addElement("ma");
        glregEnds_.addElement("a");
        glregEnds_.addElement("um");
        glregEnds_.addElement("on");
        glregEnds_.addElement("sis");
        glregEnds_.addElement("is");
        glregEnds_.addElement("men");
        glregEnds_.addElement("ex");
        glregEnds_.addElement("x");
    }
}
