package gov.nih.nlm.nls.lexCheck.CheckCont;
import java.util.*;
import gov.nih.nlm.nls.lvg.Util.UnicodeUtil;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.Api.*;
/*****************************************************************************
* This class provides a Java class to check the Spelling variants of a 
* lexRecord.
* <ul>
* <li>No duplicates - with fix option by removing duplicates
* <li>check glreg ending for noun
* <li>check regd ending for adj and verb
* </ul>
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class CheckSpellingVars
{
    // private constructor
    private CheckSpellingVars()
    {
    }
    // public methods
    // check content itself
    public static boolean CheckContent(LexRecord lexRecord)
    {
        // check extra space
        boolean spaceFlag = CheckContent.CheckSpacesForList(lexRecord, 
            LexRecordUtil.CONTENT_SV); 
        boolean validFlag = spaceFlag;
        return validFlag;
    }
    // check current content with other contents in the same record
    public static boolean CheckContents(LexRecord lexRecord)
    {
        // check duplicates
        boolean dupFlag = CheckDuplicates(lexRecord); 
        boolean glregFlag = CheckGlreg(lexRecord); 
        boolean regdFlag = CheckRegd(lexRecord);
        boolean validFlag = dupFlag && glregFlag && regdFlag;
        return validFlag;
    }
    // check correct ending if it is verb or adj and regd
    private static boolean CheckRegd(LexRecord lexRecord)
    {
        Vector<String> spList = lexRecord.GetSpellingVars();
        boolean validFlag = true;
        for(String spItem:spList)
        {
            boolean regdFlag = CheckEntry.CheckRegd(lexRecord, spItem, 
                LexRecordUtil.CONTENT_SV);
            validFlag = regdFlag && validFlag;
        }
        return validFlag;    
    }
    
    // check correct ending if it is noun and glreg
    private static boolean CheckGlreg(LexRecord lexRecord)
    {
        Vector<String> spList = lexRecord.GetSpellingVars();
        boolean validFlag = true;
        for(String spItem:spList)
        {
            boolean glregFlag = CheckEntry.CheckGlreg(lexRecord, spItem, 
                LexRecordUtil.CONTENT_SV);
            validFlag = glregFlag && validFlag;
        }
        return validFlag;    
    }
    
    // check for any duplicates among base and spellingVars 
    private static boolean CheckDuplicates(LexRecord lexRecord) 
    {
        boolean validFlag = true;
        int contentType = LexRecordUtil.CONTENT_SV;
        String base = lexRecord.GetBase();
        Vector<String> svList = lexRecord.GetSpellingVars();
        Vector<String> uSvList = new Vector<String>();
        // go through each item in the lists
        for(int i = 0; i < svList.size(); i++)
        {
            String sv = svList.elementAt(i);
            // duplicate item
            if((sv.equals(base) == true)    // duplicate with base
            || (uSvList.contains(sv) == true))
            {
                validFlag = false && validFlag;
                ErrMsgUtilLexRecord.AddContentErrMsg(contentType, 
                    ErrMsgUtilLexRecord.ERR_DUPLICATE, sv, lexRecord);
            }
            else    // add to unique list
            {
                uSvList.addElement(sv);
            }
        }
        // update fixed lexRecord
        if(validFlag == false)
        {
            lexRecord.SetSpellingVars(uSvList);
        }
        return validFlag;
    }
    // data member
}
