package gov.nih.nlm.nls.lexCheck.CheckCont;
import java.util.*;
import java.io.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.Api.*;
/*****************************************************************************
* This class provides a Java class to check cross-ref EUI on acronyms.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class CrossCheckAcrEui
{
    // private constructor
    private CrossCheckAcrEui()
    {
    }
    // lexRecord is automatically fixed
    public static boolean Check(LexRecord lexRecord, 
        HashSet<String> notBaseFormSet) 
    {
        boolean validFlag = true;
        Vector<String> acrList = lexRecord.GetAcronyms();    // expansion
        String acrCat = lexRecord.GetCategory();
        for(int i = 0; i < acrList.size(); i++)
        {
            String acr = acrList.elementAt(i);
            // tokenize acronym
            int index1 = acr.indexOf(LexRecordUtil.FS_STR);
            String acrCit = new String();    // expansion
            String acrEui  = new String();
            if(index1 > 0) // for acr = citation|Eui
            {
                acrCit = acr.substring(0, index1);
                acrEui = acr.substring(index1+1);
            }
            else    // for acr = citation
            {
                acrCit = acr;
            }
            // check cross-ref EUIs
            String citCat = acrCit + LexRecordUtil.FS_STR + acrCat;
            HashSet<String> euisByCit = 
                CrossCheckDupLexRecords.GetEuisByCitCat(citCat);
            
            if(euisByCit == null)    // eui does not exist
            {
                if(acrEui.length() > 0)    // eui exist
                {
                    // auto-fix
                    acrList.set(i, acrCit);
                    // sent auto-fix msg
                    validFlag = false;
                    ErrMsgUtilLexicon.AddContentErrMsg(
                        LexRecordUtil.CROSS_CHK_ACR,
                        ErrMsgUtilLexicon.ERR_NO_EUI, 
                        acr + " - None", lexRecord);
                }
                else    // no acrEui    
                {
                    // no EUI matches: send msg to add to to-do list
                    validFlag = false;
                    // send errMsg only if expansion is not one of notBaseForm
                    if(notBaseFormSet.contains(citCat) == false)
                    {
                        ErrMsgUtilLexicon.AddContentErrMsg(
                            LexRecordUtil.CROSS_CHK_ACR,
                            ErrMsgUtilLexicon.ERR_NEW_EUI, 
                            acr + " - New", lexRecord);
                    }
                }
            }
            else if (euisByCit.size() == 1)    // single EUI
            {
                Vector<String> euiList = new Vector<String>(euisByCit);
                String newEui = euiList.elementAt(0);
                if(acrEui.length() > 0)
                {
                    if(euisByCit.contains(acrEui) == true)
                    {
                        // One EUI match, do nothing, correct
                    }
                    else    // wrong EUI
                    {
                        // sent warning msg
                        validFlag = false;
                        ErrMsgUtilLexicon.AddContentErrMsg(
                            LexRecordUtil.CROSS_CHK_ACR,
                            ErrMsgUtilLexicon.ERR_WRONG_EUI, 
                            acr + " - " + newEui, lexRecord);
                    }
                }
                else    // no acrEui => Add it in
                {
                    // auto-fix
                    String newAcr = acr + LexRecordUtil.FS_STR + newEui;
                    acrList.set(i, newAcr);
                    // sent out auto fix msg
                    validFlag = false;
                    ErrMsgUtilLexicon.AddContentErrMsg(
                        LexRecordUtil.CROSS_CHK_ACR,
                        ErrMsgUtilLexicon.ERR_MISS_EUI, 
                        acr + " - " + newEui, lexRecord);
                }
            }
            else    // multiple EUIs
            {
                Vector<String> euiList = new Vector<String>(euisByCit);
                if(acrEui.length() > 0)
                {
                    if(euisByCit.contains(acrEui) == true)
                    {
                        // One EUI match, do nothing, correct
                    }
                    else    // no eui even multiple matched EUI found
                    {
                        // sent warning msg
                        validFlag = false;
                        ErrMsgUtilLexicon.AddContentErrMsg(
                            LexRecordUtil.CROSS_CHK_ACR,
                            ErrMsgUtilLexicon.ERR_WRONG_EUIS, 
                            acr + " - " + euiList, lexRecord);
                    }
                }
                else    // no acrEui
                {
                    // sent out msg
                    validFlag = false;
                    ErrMsgUtilLexicon.AddContentErrMsg(
                        LexRecordUtil.CROSS_CHK_ACR,
                        ErrMsgUtilLexicon.ERR_MISS_EUIS, 
                        acr + " - " + euiList, lexRecord);
                }
            }
        }
        return validFlag;
    }
    // data member
}
