package gov.nih.nlm.nls.lexCheck.CheckCont;
import java.util.*;
import java.io.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.Api.*;
/*****************************************************************************
* This class provides a Java class to check cross-ref EUI on nominalization.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class CrossCheckNomEui
{
    // private constructor
    private CrossCheckNomEui()
    {
    }
    // lexRecord is automatically fixed
    public static boolean Check(LexRecord lexRecord) 
    {
        boolean validFlag = true;
        Vector<String> nomList = lexRecord.GetNominalizations();
        for(int i = 0; i < nomList.size(); i++)
        {
            String nom = nomList.elementAt(i);
            // tokenize nominalization
            int index1 = nom.indexOf(LexRecordUtil.FS_STR);
            int index2 = nom.indexOf(LexRecordUtil.FS_STR, index1+1);
            String nomCit = nom.substring(0, index1);
            String nomCat = new String();
            String nomEui  = new String();
            if(index2 > 0) // for nom = citation|category|Eui
            {
                nomCat = nom.substring(index1+1, index2);
                nomEui = nom.substring(index2+1);
            }
            else    // for nom = citation|category
            {
                nomCat = nom.substring(index1+1);
            }
            // check cross-ref EUIs
            String citCat = nomCit + LexRecordUtil.FS_STR + nomCat;
            HashSet<String> euisByCit = 
                CrossCheckDupLexRecords.GetEuisByCitCat(citCat);
            
            if(euisByCit == null)    // no eui found by cit|cat
            {
                if(nomEui.length() > 0)    // eui exist
                {
                    // auto-fix
                    nomList.set(i, citCat);
                    // sent auto-fix msg
                    validFlag = false;
                    ErrMsgUtilLexicon.AddContentErrMsg(
                        LexRecordUtil.CROSS_CHK_NOM,
                        ErrMsgUtilLexicon.ERR_NO_EUI, 
                        nom + " - None", lexRecord);
                }
                else    // no nomEui    
                {
                    // no EUI matches: send msg to add to to-do list
                    validFlag = false;
                    ErrMsgUtilLexicon.AddContentErrMsg(
                        LexRecordUtil.CROSS_CHK_NOM,
                        ErrMsgUtilLexicon.ERR_NEW_EUI, 
                        nom + " - New", lexRecord);
                }
            }
            else if (euisByCit.size() == 1)    // single EUI
            {
                Vector<String> euiList = new Vector<String>(euisByCit);
                String newEui = euiList.elementAt(0);
                if(nomEui.length() > 0)
                {
                    if(euisByCit.contains(nomEui) == true)
                    {
                        // One EUI match, do nothing, correct
                    }
                    else
                    {
                        // sent warning msg
                        validFlag = false;
                        ErrMsgUtilLexicon.AddContentErrMsg(
                            LexRecordUtil.CROSS_CHK_NOM,
                            ErrMsgUtilLexicon.ERR_WRONG_EUI, 
                            nom + " - " + newEui, lexRecord);
                    }
                }
                else    // no nomEui => Add it in
                {
                    // auto-fix
                    String newNom = nom + LexRecordUtil.FS_STR + newEui;
                    nomList.set(i, newNom);
                    // sent out auto fix msg
                    validFlag = false;
                    ErrMsgUtilLexicon.AddContentErrMsg(
                        LexRecordUtil.CROSS_CHK_NOM,
                        ErrMsgUtilLexicon.ERR_MISS_EUI, 
                        nom + " - " + newEui, lexRecord);
                }
            }
            else    // multiple EUIs
            {
                Vector<String> euiList = new Vector<String>(euisByCit);
                if(nomEui.length() > 0)
                {
                    if(euisByCit.contains(nomEui) == true)
                    {
                        // One EUI match, do nothing, correct
                    }
                    else    // no eui even multiple matched EUI found
                    {
                        // sent warning msg
                        validFlag = false;
                        ErrMsgUtilLexicon.AddContentErrMsg(
                            LexRecordUtil.CROSS_CHK_NOM,
                            ErrMsgUtilLexicon.ERR_WRONG_EUIS, 
                            nom + " - " + euiList, lexRecord);
                    }
                }
                else    // no nomEui
                {
                    // sent out msg
                    validFlag = false;
                    ErrMsgUtilLexicon.AddContentErrMsg(
                        LexRecordUtil.CROSS_CHK_NOM,
                        ErrMsgUtilLexicon.ERR_MISS_EUIS, 
                        nom + " - " + euiList, lexRecord);
                }
            }
        }
        return validFlag;
    }
    // data member
}
