package gov.nih.nlm.nls.lexCheck.CheckCont;
import java.util.*;
import java.io.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.Api.*;
/*****************************************************************************
* This class provides a Java class to cross check on symmetric nominalization.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class CrossCheckNomSym
{
    // private constructor
    private CrossCheckNomSym()
    {
    }
    // lexRecord is automatically fixed
    public static boolean Check(Vector<LexRecord> lexRecords) 
    {
        // loads hashTable euiNomObjTable_
        LoadEuiNomObjTable(lexRecords);
        // check
        boolean validFlag = true;
        Enumeration<String> euis = euiNomObjTable_.keys();
        while(euis.hasMoreElements() == true)
        {
            String eui = euis.nextElement();
            LexRecordNomObj lexRecordNomObj = euiNomObjTable_.get(eui);
            String cit = lexRecordNomObj.GetBase();
            String cat = lexRecordNomObj.GetCategory();
            String tarNom = cit + LexRecordUtil.FS_STR + cat
                + LexRecordUtil.FS_STR + eui;
            Vector<String> nomList = lexRecordNomObj.GetNominalizations();
            for(int i = 0; i < nomList.size(); i++)
            {
                String nom = nomList.elementAt(i);
                // tokenize nominalization
                int index1 = nom.indexOf(LexRecordUtil.FS_STR);
                int index2 = nom.indexOf(LexRecordUtil.FS_STR, index1+1);
                String nomCit = nom.substring(0, index1);
                String nomCat = new String();
                String nomEui  = new String();
                if(index2 > 0) // for nom = citation|category|Eui
                {
                    nomCat = nom.substring(index1+1, index2);
                    nomEui = nom.substring(index2+1);
                    // cross check symmetric
                    LexRecordNomObj tarLexRecordNomObj 
                        = euiNomObjTable_.get(nomEui);
                    // check cross nom
                    if(tarLexRecordNomObj == null)    // no such nom
                    {
                        validFlag = false;
                        ErrMsgUtilLexicon.AddContentErrMsg(
                            LexRecordUtil.CROSS_CHK_NOM,
                            ErrMsgUtilLexicon.ERR_SYM_NONE, 
                            tarNom + ": " + nom);
                    }
                    else    // cross nom record exist
                    {
                        Vector<String> tarNomList 
                            = tarLexRecordNomObj.GetNominalizations();
                        // check cross category
                        if(!nomCat.equals(tarLexRecordNomObj.GetCategory()))
                        {
                            validFlag = false;
                            ErrMsgUtilLexicon.AddContentErrMsg(
                                LexRecordUtil.CROSS_CHK_NOM,
                                ErrMsgUtilLexicon.ERR_SYM_CAT, 
                                tarNom + ": " + nom);
                        }
                        // check cross citation
                        else if(!nomCit.equals(tarLexRecordNomObj.GetBase()))
                        {
                            validFlag = false;
                            ErrMsgUtilLexicon.AddContentErrMsg(
                                LexRecordUtil.CROSS_CHK_NOM,
                                ErrMsgUtilLexicon.ERR_SYM_CIT, 
                                tarNom + ": " + nom);
                        }
                        // no nom exist in the corss record, should not happen
                        else if(tarNomList.size() == 0)    
                        {
                            validFlag = false;
                            ErrMsgUtilLexicon.AddContentErrMsg(
                                LexRecordUtil.CROSS_CHK_NOM,
                                ErrMsgUtilLexicon.ERR_SYM_NONE, 
                                tarNom + ": " + nom);
                        }
                        // no suchnom in the cross record nomList
                        else if(tarNomList.contains(tarNom) == false)
                        {
                            validFlag = false;
                            ErrMsgUtilLexicon.AddContentErrMsg(
                                LexRecordUtil.CROSS_CHK_NOM,
                                ErrMsgUtilLexicon.ERR_SYM_NONE,
                                tarNom + ": " + nom);
                        }
                    }
                }
                else    // for nom = citation|category
                {
                    // do nothing: no symmetric exist, so no need to check
                    // nomCat = nom.substring(index1+1);
                    // missing EUI already check in CrossCheckNomEui.java
                    // thsiclass only check symmetric
                }
            }
        }
        return validFlag;
    }
    // private method
    // load EUI|nomList  from Lexicon
    private static void LoadEuiNomObjTable(Vector<LexRecord> lexRecords)
    {
        int recNo = 0;
        int nomNo = 0;
        // load it only one time
        if(euiNomObjTable_ == null)
        {
            euiNomObjTable_ = new Hashtable<String, LexRecordNomObj>();
            for(LexRecord lexRecord:lexRecords)
            {
                String eui = lexRecord.GetEui();
                Vector<String> nominalizations = lexRecord.GetNominalizations();
                if(nominalizations.size() > 0)
                {
                    LexRecordNomObj lexRecordNomObj 
                        = new LexRecordNomObj(lexRecord);
                    euiNomObjTable_.put(eui, lexRecordNomObj);    
                    nomNo++;
                }
                recNo++;
            }
            System.out.println(
                "=== CrossCheckNomSym.LoadEuiNomObjTable( ) ===");
            System.out.println("-- Total lexRecord: " + recNo);
            System.out.println("-- Total nomLists: " + nomNo);
        }
    }
    // data member
    private static Hashtable<String, LexRecordNomObj> euiNomObjTable_ = null;
}
