package gov.nih.nlm.nls.lexCheck.CkLib;
import java.util.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
/*****************************************************************************
* This class checks code of a line.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class CheckCode
{
    // public method
    /**
    * Check the code of the input line.
    *
    * @param   lineObject  the java object of the input line
    * @param   printFlag   the flag for print out check result
    * @param   st       the state of current checking
    * @param   lexObj   the current object of lexical record
    * @param   checkObject  the java object of checking
    * @param   updateLex    the java object of updateing lexical record
    * @param   frequency    the allowable frequency of appearance
    * @param   checkLength   flag of checking length or not
    *
    * @return  true or false for a legal or illegal code of a line
    */
    public static boolean Check(LineObject lineObject, boolean printFlag,
        CheckSt st, LexRecord lexObj, CheckObject checkObject, 
        UpdateLex updateLex, int frequency, boolean checkLength)
    {
        boolean flag = false;
        switch(frequency)
        {
            case FQ_ONE:    // only show up one time
                flag = CheckOne(lineObject, printFlag, st, lexObj, checkObject,
                    updateLex, checkLength, true);
                break;
            case FQ_ZERO_ONE:     // not shown up or only one time
                flag = CheckZeroOne(lineObject, printFlag, st, lexObj, 
                    checkObject, updateLex, checkLength);
                break;
            case FQ_ZERO_MANY:    // 
                flag = CheckZeroMany(lineObject, printFlag, st, lexObj, 
                    checkObject, updateLex, checkLength);
                break;
            case FQ_ONE_MANY:
                flag = CheckOneMany(lineObject, printFlag, st, lexObj,
                    checkObject, updateLex, checkLength);
                break;
            case FQ_ONE_WHOLE_LINE:
                flag = CheckOneWholeLine(lineObject, printFlag, st, lexObj, 
                    checkObject, updateLex);
                break;
            case FQ_ZERO_ONE_WHOLE_LINE:
                flag = CheckZeroOneWholeLine(lineObject, printFlag, st, lexObj, 
                    checkObject, updateLex);
                break;
        }
        return flag;
    }
    // check if there is one and only one slot
    private static boolean CheckOne(LineObject lineObject, boolean printFlag,
        CheckSt st, LexRecord lexObj, CheckObject checkObject, 
        UpdateLex updateLex, boolean checkLength, boolean updateState)
    {
        // must read in the next line after this method
        lineObject.SetGoToNext(true);
        // Check slot - starting string
        boolean flag = LineCheck.CheckStartStr(lineObject, printFlag, 
            checkObject);
        st.UpdateLastState();
            
        if(flag == true)
        {
            TokenObject tokenObject = new TokenObject();
            // Check slot & filler
            flag = LineCheck.CheckSlotFiller(lineObject, printFlag, checkObject,
                tokenObject, checkLength);
            // assign filler to lexRecord
            if(flag == true) 
            {
                // update state
                if(updateState == true)
                {
                    st.UpdateCurState(checkObject.GetNextState());
                }
                // udpate lexical record
                if(updateLex != null)
                {
                    updateLex.Update(lexObj, tokenObject.GetToken());
                }
            }
        }
        return flag;
    }
    private static boolean CheckZeroOne(LineObject lineObject, 
        boolean printFlag, CheckSt st, LexRecord lexObj, 
        CheckObject checkObject, UpdateLex updateLex, boolean checkLength)
    {
        // check if the strat string is belong to those following
        String line = lineObject.GetLine();
        boolean flag = checkObject.IsNextStartStr(line);
        // in case of next line, zero, no such line
        if(flag == true)
        {
            st.UpdateCurState(checkObject.GetNextState());
            lineObject.SetGoToNext(false);
            return flag;
        }
        // not next line, in case of first time of using this method
        else if(st.GetCurState() != st.GetLastState())
        {
            st.UpdateLastState();
            flag = CheckOne(lineObject, printFlag, st, lexObj, checkObject,
                updateLex, checkLength, false);
        }
        else    // in case of not the first time
        {
            ErrMsg.PrintErrMsg(printFlag, ErrMsg.SLOT_NUMBER_ERR,        
                lineObject, line, 0, line.length(), checkObject.IsTab());
            st.UpdateLastState();
            flag = false;
        }
        return flag;
    }
    private static boolean CheckZeroMany(LineObject lineObject, 
        boolean printFlag, CheckSt st, LexRecord lexObj, 
        CheckObject checkObject, UpdateLex updateLex, boolean checkLength)
    {
        lineObject.SetGoToNext(true);
        st.UpdateLastState();
        // check if the starting string is the next line
        boolean flag = checkObject.IsNextStartStr(lineObject.GetLine());
        if(flag == true)
        {
            st.UpdateCurState(checkObject.GetNextState());
            lineObject.SetGoToNext(false);
            return flag;
        }
        // Check slot - starting string
        flag = LineCheck.CheckStartStr(lineObject, printFlag, checkObject);
        if(flag == true)
        {
            TokenObject tokenObject = new TokenObject();
            // Check begin slot & filler
            flag = LineCheck.CheckSlotFiller(lineObject, printFlag, checkObject,
                tokenObject, checkLength);
            // assign filler to lexRecord
            if(flag == true)
            {
                updateLex.Update(lexObj, tokenObject.GetToken());
            }
        }
        return flag;
    }
    private static boolean CheckOneMany(LineObject lineObject, 
        boolean printFlag, CheckSt st, LexRecord lexObj, 
        CheckObject checkObject, UpdateLex updateLex, boolean checkLength)
    {
        boolean flag = false;
        // if first time check for this state
        if(st.GetCurState() != st.GetLastState())
        {
            st.UpdateLastState();
            flag = CheckOne(lineObject, printFlag, st, lexObj, checkObject,
                updateLex, checkLength, false);
        }
        else // no tthe first time
        {
            st.UpdateLastState();
            flag = CheckZeroMany(lineObject, printFlag, st, lexObj, checkObject,
                updateLex, checkLength);
        }
        return flag;
    }
    private static boolean CheckOneWholeLine(LineObject lineObject, 
        boolean printFlag, CheckSt st, LexRecord lexObj, 
        CheckObject checkObject, UpdateLex updateLex)
    {
        lineObject.SetGoToNext(true);
        // Check the whole line
        boolean flag = LineCheck.CheckWholeLine(lineObject, printFlag, 
            checkObject);
            
        if(flag == true)
        {
            // update state
            st.UpdateLastState();
            st.UpdateCurState(checkObject.GetNextState());
            // udpate lexical record
            if(updateLex != null)
            {
                updateLex.Update(lexObj, lineObject.GetLine());
            }
        }
        return flag;
    }
    private static boolean CheckZeroOneWholeLine(LineObject lineObject, 
        boolean printFlag, CheckSt st, LexRecord lexObj, 
        CheckObject checkObject, UpdateLex updateLex)
    {
        boolean flag = checkObject.IsNextStartStr(lineObject.GetLine());
        // in case of find string of the following lines,
        if(flag == true)
        {
            st.UpdateCurState(checkObject.GetNextState());
            lineObject.SetGoToNext(false);
            return flag;
        }
        // in case of first time
        else if(st.GetCurState() != st.GetLastState())
        {
            st.UpdateLastState();
            flag = CheckOneWholeLine(lineObject, printFlag, st, lexObj,
                checkObject, updateLex);
        }
        else    // in case of more than once
        {
            String line = lineObject.GetLine();
            st.UpdateLastState();
            ErrMsg.PrintErrMsg(printFlag, ErrMsg.SLOT_NUMBER_ERR, lineObject,
                line, 0, line.length(), checkObject.IsTab());
        }
        return flag;
    }
    // data member
    /** appear frequency one */
    public final static int FQ_ONE = 1;
    /** appear frequency zero or one */
    public final static int FQ_ZERO_ONE = 2;
    /** appear frequency zero or many */
    public final static int FQ_ZERO_MANY = 3;
    /** appear frequency one or many */
    public final static int FQ_ONE_MANY = 4;
    /** appear frequency one with whole line pass to check */
    public final static int FQ_ONE_WHOLE_LINE = 5;
    /** appear frequency once zero or one with whole line pass to check */
    public final static int FQ_ZERO_ONE_WHOLE_LINE = 6;
}
