package gov.nih.nlm.nls.lexCheck.CkLib;
import java.util.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
/*****************************************************************************
* This class checks line object, different pattern.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class LineCheck
{
    // public method
    /**
    * check if the line starts with the assigned start string
    *
    * @param   lineObject  the java object of the input line
    * @param   printFlag   the flag for print out check result
    * @param   checkObject the java object of checking
    *
    * @return  true or false for legal or illegal starting string
    */
    public static boolean CheckStartStr(LineObject lineObject, 
        boolean printFlag, CheckObject checkObject)
    {
        String line = lineObject.GetLine();
        String startStr = checkObject.GetStartStr();
        
        boolean flag = line.startsWith(startStr);
        boolean isTab = checkObject.IsTab();
        int beginIndex = 0;
        int endIndex = startStr.length()-1;
        if(isTab == true)
        {
            beginIndex = 1;
        }
        if(flag == false)
        {
            ErrMsg.PrintErrMsg(printFlag, checkObject.GetStartErrMsg(),
                lineObject, null, beginIndex, endIndex, isTab);
        }
        return flag;
    }
    // check if the whole line
    /**
    * check if the whole line is the same as the assigned string
    *
    * @param   lineObject  the java object of the input line
    * @param   printFlag   the flag for print out check result
    * @param   checkObject the java object of checking
    *
    * @return  true or false for legal or illegal starting string
    */
    public static boolean CheckWholeLine(LineObject lineObject, 
        boolean printFlag, CheckObject checkObject)
    {
        String line = lineObject.GetLine();
        String startStr = checkObject.GetStartStr();
        
        boolean flag = line.equals(startStr);
        boolean isTab = checkObject.IsTab();
        int beginIndex = 0;
        int endIndex = startStr.length();
        if(isTab == true)
        {
            beginIndex = 1;
        }
        if(flag == false)
        {
            ErrMsg.PrintErrMsg(printFlag, checkObject.GetStartErrMsg(),
                lineObject, null, beginIndex, endIndex, isTab);
        }
        return flag;
    }
    /**
    * Retrieve the start string by giving the delimiter
    *
    * @param   lineObject  the java object of the input line
    * @param   delim   delimiter for tokenizing the starting string
    *
    * @return  the starting string delimited by the delimiter.
    */
    public static String GetStartStr(LineObject lineObject, String delim)
    {
        String line = lineObject.GetLine();
        StringTokenizer buf = new StringTokenizer(line, delim);
        String startStr = new String();
        if(buf.hasMoreTokens())
        {
            startStr = buf.nextToken();
        }
        
        return startStr;
    }
    /**
    * Check Slot and filler 
    *
    * @param   lineObject   the java object of the input line
    * @param   printFlag    the flag for print out check result
    * @param   checkObject  the java object of checking
    * @param   tokenObject  the java object of tokenization
    * @param   checkLength  flag of checking length or not
    *
    * @return  true or false for a legal or illegal slot and filler
    */
    public static boolean CheckSlotFiller(LineObject lineObject, 
        boolean printFlag, CheckObject checkObject, TokenObject tokenObject, 
        boolean checkLength)
    {
        String line = lineObject.GetLine();
        boolean isTab = checkObject.IsTab();
        // check slot xxx=
        String slot = null;
        String filler = null;
        String delim = checkObject.GetDelim();
        // tokenize slot and filler
        int index = line.indexOf(delim);
        if(index != -1)
        {
            if(delim == "=")
            {
                slot = line.substring(0, index+1);
                filler = line.substring(index+1);
            }
            else // for the case of intran;part( )
            {
                slot = line.substring(0, index+1);
                filler = line;
            }
        }
        else
        {
            ErrMsg.PrintErrMsg(printFlag, ErrMsg.SLOT_FILLER_ERR,
                lineObject, line, 0, line.length(), isTab);
            return false;
        }
        // compare the start string
        boolean flag = false;
        String startStr = checkObject.GetStartStr();
        if(startStr != null)
        {
            flag = slot.equals(startStr);
        }
        // print out error message for error slot=
        if(flag == false)
        {
            ErrMsg.PrintErrMsg(printFlag, checkObject.GetStartErrMsg(), 
                lineObject, slot, 0, index, isTab);
            return flag;
        }
        // Check generic format for filler
        flag = CheckFillerFormat.IsLegalFormat(printFlag, lineObject, filler,
            index, isTab, checkLength);
        if(flag == false)
        {
            return false;
        }
    
        // check filler format
        CheckFormat fillerFormat = checkObject.GetFillerFormat();
        if(fillerFormat != null)
        {
            flag = fillerFormat.IsLegalFormat(filler);
            if(flag == false)
            {
                ErrMsg.PrintErrMsg(printFlag, checkObject.GetFillerErrMsg(), 
                    lineObject, filler, index+1, index+filler.length(), 
                    isTab);
                return flag;
            }
        }
        //set token object
        if((flag == true) && (tokenObject != null))
        {
            tokenObject.SetToken(filler);
        }
        // return flag
        return flag;
    }
}
