package gov.nih.nlm.nls.lexCheck.Lib;
import java.util.*;
/*****************************************************************************
* This class provides a Java object class for adjective entry.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class AdjEntry
{
    // public constructors
    /**
    *    Creates a default adjective entry object
    */
    public AdjEntry()
    {
        variants_ = new Vector<String>();
        position_ = new Vector<String>();
        compl_ = new Vector<String>();
        nominalization_ = new Vector<String>();
        stative_ = false;
    }
    // public method
    /**
    * Get the collection of inflectional variants of an adjective entry
    *
    * @return  a Vector with inflectional variant elements.
    */
    public Vector<String> GetVariants()
    {
        return variants_;
    }
    /**
    * Get the collection of positions of an adjective entry
    *
    * @return  a Vector with position elements.
    */
    public Vector<String> GetPosition()
    {
        return position_;
    }
    /**
    * Get the collection of complements of an adjective entry
    *
    * @return  a Vector with complement elements.
    */
    public Vector<String> GetCompl()
    {
        return compl_;
    }
    /**
    * Get the collection of nominalizations of an adjective entry
    *
    * @return  a Vector with nominalization elements.
    */
    public Vector<String> GetNominalization()
    {
        return nominalization_;
    }
    /**
    * Get the status of stative of an adjective entry
    *
    * @return  true or false for the status of stative
    */
    public boolean IsStative()
    {
        return stative_;
    }
    /**
    * Add an inflectional variant to the collection of inflectional variants 
    * of an adjective entry.
    *
    * @param  variant  an inflectional variant to be added.
    */
    public void AddVariant(String variant)
    {
        variants_.add(variant);
    }
    /**
    * Set the collection of inflectional variants of an adjective entry
    *
    * @param  variants   a Vector of inflectional variants to be set.
    */
    public void SetVariants(Vector<String> variants)
    {
        variants_ = variants;
    }
    /**
    * Add a position to the collection of inflectional variants 
    * of an adjective entry.
    *
    * @param  position   a position variant to be added.
    */
    public void AddPosition(String position)
    {
        position_.add(position);
    }
    /**
    * Set the collection of position of an adjective entry
    *
    * @param  position   a Vector of position to be set.
    */
    public void SetPosition(Vector<String> position)
    {
        position_ = position;
    }
    /**
    * Add an complement to the collection of inflectional variants 
    * of an adjective entry.
    *
    * @param  compl   an complement to be added.
    */
    public void AddCompl(String compl)
    {
        compl_.add(compl);
    }
    /**
    * Set the collection of complements of an adjective entry
    *
    * @param  compl   a Vector of complements to be set.
    */
    public void SetCompl(Vector<String> compl)
    {
        compl_ = compl;
    }
    /**
    * Add a nominalization to the collection of inflectional variants 
    * of an adjective entry.
    *
    * @param  nominalization   an nominalization to be added.
    */
    public void AddNominalization(String nominalization)
    {
        nominalization_.add(nominalization);
    }
    /**
    * Set the collection of nominalization of an adjective entry
    *
    * @param  nominalization   a Vector of nominalization to be set.
    */
    public void SetNominalization(Vector<String> nominalization)
    {
        nominalization_ = nominalization;
    }
    /**
    * Set the status of stative of an adjective entry
    *
    * @param  stative   the status of stative to be set
    */
    public void SetStative(boolean stative)
    {
        stative_ = stative;
    }
    /**
    * Get the text format of the adjective entry
    *
    * @return  text format of the adjective entry
    */
    public String GetText()
    {
        String text = new String();
        text = TextLib.AddToText(text, "variants=", variants_, 1);
        text = TextLib.AddToText(text, "position=", position_, 1);
        text = TextLib.AddToText(text, "compl=", compl_, 1);
        text = TextLib.AddToText(text, "stative", stative_, 1);
        text = TextLib.AddToText(text, "nominalization=", nominalization_, 1);
        return text;
    }
    /**
    * Get the xml format of the adjective entry
    *
    * @return  xml format of the adjective entry
    */
    public String GetXml()
    {
        boolean convertFlag = true;
        String xml = new String();
        xml = XmlLib.AddToXml(xml, "<adjEntry>", 2); 
        xml = XmlLib.AddToXml(xml, "<variants>", "</variants>", variants_, 3,
            convertFlag);
        if(position_ != null)
        {
            for(int i = 0; i < position_.size(); i++)
            {
                String positionTag = "<position type=\"" 
                    + position_.elementAt(i) + "\"/>";
                xml = XmlLib.AddToXml(xml, positionTag, 3);
            }
        }
        xml = XmlLib.AddToXml(xml, "<compl>", "</compl>", compl_, 3,
            convertFlag);
        xml = XmlLib.AddToXml(xml, "<stative/>", stative_, 3);
        xml = XmlLib.AddToXml(xml, "<nominalization>", "</nominalization>", 
            nominalization_, 3, convertFlag);
        xml = XmlLib.AddToXml(xml, "</adjEntry>", 2); 
        return xml;
    }
    // data member
    private Vector<String> variants_ = new Vector<String>();
    private Vector<String> position_ = new Vector<String>();
    private Vector<String> compl_ = new Vector<String>();
    private boolean stative_ = false;
    private Vector<String> nominalization_ = new Vector<String>();
}
