package gov.nih.nlm.nls.lexCheck.Lib;
import java.util.*;
/*****************************************************************************
* This class provides a Java class for inflection and inflectional variants.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class Agreement
{
    /**
    * Creates a default Agrument (for LRAGR) by specifing eui, uninflected 
    * term, inflection, uninflectional variant, category, and citation form. 
    *
    * @param  eui   unique entry identifier
    * @param  var   inflectional variant
    * @param  cat   category
    * @param  agr   agreement
    * @param  base  uninflectional (base) form
    * @param  cit   citation form (the citated base form)
    */
    public Agreement(String eui, String var, String cat, String agr,
        String base, String cit)
    {
        eui_ = eui;
        var_ = var;
        cat_ = cat;
        agr_ = agr;
        base_ = base;
        cit_ = cit;
    }
    // public method
    /**
    * Get category
    *
    * @return category name  
    */
    public String GetCat()
    {
        return cat_;
    }
    /**
    * Get citation
    *
    * @return citation form  
    */
    public String GetCit()
    {
        return cit_;
    }
    /**
    * Get Eui
    *
    * @return Eui (Entry Unique Identifier)  
    */
    public String GetEui()
    {
        return eui_;
    }
    /**
    * Get base - uninflectional variant
    *
    * @return base
    */
    public String GetBase()
    {
        return base_;
    }
    /**
    * Get agreement
    *
    * @return   String agremment
    */
    public String GetAgreement()
    {
        return agr_;
    }
    /**
    * Get inflectional variant
    *
    * @return   inflectional variant
    */
    public String GetVar()
    {
        return var_;
    }
    /**
    * Set the category
    *
    * @param   cat catogory 
    */
    public void SetCat(String cat)
    {
        cat_ = cat;
    }
    /**
    * Set the citation
    *
    * @param   cit citation 
    */
    public void SetCit(String cit)
    {
        cit_ = cit;
    }
    /**
    * Set the eui
    *
    * @param   eui   entry unque identifier 
    */
    public void SetEui(String eui)
    {
        eui_ = eui;
    }
    /**
    * Set the base form
    *
    * @param   base   uninflectional form (base) 
    */
    public void SetBase(String base)
    {
        base_ = base;
    }
    /**
    * Set inflectional
    *
    * @param   agr   agreement
    */
    public void SetAgreement(String agr)
    {
        agr_ = agr;
    }
    /**
    * Set the inflectional variant
    *
    * @param   var   inflectional variant
    */
    public void SetVar(String var)
    {
        var_ = var;
    }
    // data member
    private String var_ = null;            // inflectional variant
    private String cat_ = null;            // category
    private String agr_ = null;            // agreement
    private String eui_ = null;            // eui
    private String base_ = null;        // uninflection - base
    private String cit_ = null;            // citation
}
