package gov.nih.nlm.nls.lexCheck.Lib;
import java.io.*;
import java.util.*;
/*****************************************************************************
* This class provides a way of storing and retrieving configurations through a
* Configuation object. 
*
* <p><b>History:</b>
* <ul>
* <li>SCR-51, chlu, 12-10-15, build with java 1.8
* </ul>
*
* @author NLM NLS Development Team
*
* @version    V-2016
****************************************************************************/
public class Configuration
{
    // public constructor
    /**
    * Create a Configuration object.  There are two ways of reading 
    * configuration files.  First, finding xxx.properties from Java class path.
    * Second, finding file by the specified path. 
    *  
    * @param  fName  the path of the configuration file or base name when
    * using class path.
    * @param  useClassPath  a flag of finding configurationfile from class path
    */
    public Configuration(String fName, boolean useClassPath)
    {
        SetConfiguration(fName, useClassPath);
    }
    // public methods
    /**
    * Get a value from configuration file by specifying the key.
    *
    * @param  key  key (name) of the configuration value to be get
    *
    * @return  the value of the configuration item in a string format
    */
    public String GetConfiguration(String key)
    {
        String out = config_.getString(key);
        return out;
    }
    /**
    * Get a value from configuration file by specifying the key.
    * Overwrite the value if it is specified inthe properties.
    *
    * @param  key  key (name) of the configuration value to be get
    * @param  conf  lexCheck configuration java object
	* @param  properties properties to be overwrite in the configuration
    *
    * @return  the value of the configuration item in a string format
    */
    public static String OverWriteProperty(String key, Configuration conf,
        Hashtable<String, String> properties)
    {
        String property = conf.GetConfiguration(key);
        String value = properties.get(key);
        if(value != null)
        {
            property = value;
        }
        return property;
    }
    /**
    * Get system level informatio from configuration.  This includes
    * LC_DIR
    *
    * @return  the value of the configuration item in a string format
    */
    public String GetInformation()
    {
        StringBuffer buffer = new StringBuffer();
        buffer.append("LC_DIR: [" + GetConfiguration(LC_DIR) + "]");
        buffer.append(LS_STR);
        return buffer.toString();
    }
    // private methods
    private void SetConfiguration(String fName, boolean useClassPath)
    {
        try
        {
            // get config data from fName.properties in class path
            if(useClassPath == true)
            {
                config_ = 
                    (PropertyResourceBundle) ResourceBundle.getBundle(fName);
            }
            else // get config data from fName (path) file
            {
                FileInputStream file = new FileInputStream(fName);
                config_ = new PropertyResourceBundle(file);
                file.close();
            }
        }
        catch (Exception e)
        {
            System.err.println("** Configuration Error: " + e.getMessage());
            System.err.println(
                "** Error: problem of opening/reading config file: '" +
                fName + "'. Use -x option to specify the config file path.");
        }
    }
    // data member
    /** key for the path of LVG directory defined in configuration file */
    public final static String LC_DIR = "LC_DIR";
    /** key for the text indent defined in configuration file */
    public final static String TEXT_INDENT = "TEXT_INDENT";
    public final static String XML_INDENT = "XML_INDENT";
    public final static String XML_HEADER = "XML_HEADER";
    public final static String PREPOSITION_FILE = "PREPOSITION_FILE";
    public final static String IRREG_EXP_FILE = "IRREG_EXP_FILE";
    // private data member
    private PropertyResourceBundle config_ = null;
    private final static String LS_STR 
        = System.getProperty("line.separator").toString(); 
}
