package gov.nih.nlm.nls.lexCheck.Lib;
import java.util.*;
/*****************************************************************************
* This class provides a Java object for modal entry.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class ModalEntry
{
    /**
    *    Creates a default modal entry object
    */
    public ModalEntry()
    {
        variant_ = new Vector<String>();
    }
    // public method
    /**
    * Get the collection of inflectional variants of a modal entry
    *
    * @return  a Vector with inflectional variants elements.
    */
    public Vector<String> GetVariant()
    {
        return variant_;
    }
    /**
    * Add an inflectional variant to the collection of inflectional variants 
    * of a modal entry.
    *
    * @param  variant inflectional variant to be added.
    */
    public void AddVariant(String variant)
    {
        variant_.add(variant);
    }
    /**
    * Set the collection of inflectional variants of a modal entry
    *
    * @param  variant Vector of inflectional variants to be set.
    */
    public void SetVariant(Vector<String> variant)
    {
        variant_ = variant;
    }
    /**
    * Get the text format of the modal entry
    *
    * @return  text format of the modal entry
    */
    public String GetText()
    {
        String text = new String();
        text = TextLib.AddToText(text, "variant=", variant_, 1);
        return text;
    }
    /**
    * Get the xml format of the modal entry
    *
    * @return  xml format of the modal entry
    */
    public String GetXml()
    {
        boolean convertFlag = true;
        String xml = new String();
        xml = XmlLib.AddToXml(xml, "<modalEntry>", 2); 
        xml = XmlLib.AddToXml(xml, "<variant>", "</variant>", variant_, 3,
            convertFlag);
        xml = XmlLib.AddToXml(xml, "</modalEntry>", 2); 
        return xml;
    }
    // data member
    private Vector<String> variant_ = new Vector<String>();
}
