package gov.nih.nlm.nls.lexCheck.Lib;
import java.util.*;
/*****************************************************************************
* This class provides a Java object for pronoun entry.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class PronEntry
{
    /**
    *    Creates a default pronoun entry object
    */
    public PronEntry()
    {
        variants_ = new Vector<String>();
        gender_ = null;
        interrogative_ = false;
        type_ = new Vector<String>();
    }
    // public method
    /**
    * Get the collection of agreement variants of a pronoun entry
    *
    * @return  a Vector with agrement variant elements.
    */
    public Vector<String> GetVariants()
    {
        return variants_;
    }
    /**
    * Get the gender of a pronoun entry
    *
    * @return  gender information.
    */
    public String GetGender()
    {
        return gender_;
    }
    /**
    * Get the boolean flag of interrogatvie of a pronoun entry
    *
    * @return  the boolean flag of interrogatvie
    */
    public boolean IsInterrogative()
    {
        return interrogative_;
    }
    /**
    * Get the collection of type of a pronoun entry
    *
    * @return  a Vector with type elements.
    */
    public Vector<String> GetType()
    {
        return type_;
    }
    /**
    * Add an agreement variant to the collection of agreement variants 
    * of a pronoun entry.
    *
    * @param  variant    an agreement variant to be added.
    */
    public void AddVariant(String variant)
    {
        variants_.add(variant);
    }
    /**
    * Set the collection of agreement variants of a pronoun entry
    *
    * @param  variants   a Vector of agreement variants to be set.
    */
    public void SetVariants(Vector<String> variants)
    {
        variants_ = variants;
    }
    /**
    * Set the gender of a pronoun entry
    *
    * @param  gender   the gender to be set.
    */
    public void SetGender(String gender)
    {
        gender_ = gender;
    }
    /**
    * Set the boolean flag of interrogative of a pronoun entry
    *
    * @param  interrogative   the boolean flag of interrogative to be set.
    */
    public void SetInterrogative(boolean interrogative)
    {
        interrogative_ = interrogative;
    }
    /**
    * Add a type to the collection of types of a pronoun entry
    *
    * @param  type   the type to be added.
    */
    public void AddType(String type)
    {
        type_.add(type);
    }
    /**
    * Set the type of a pronoun entry
    *
    * @param  type   the type to be set.
    */
    public void SetType(Vector<String> type)
    {
        type_ = type;
    }
    /**
    * Get the text format of the pronoun entry
    *
    * @return  text format of the pronoun entry
    */
    public String GetText()
    {
        String text = new String();
        text = TextLib.AddToText(text, "variants=", variants_, 1);
        text = TextLib.AddToText(text, "gender=", gender_, 1);
        text = TextLib.AddToText(text, "interrogative", interrogative_, 1);
        text = TextLib.AddToText(text, "type=", type_, 1);
        return text;
    }
    /**
    * Get the xml format of the pronoun entry
    *
    * @return  xml format of the pronoun entry
    */
    public String GetXml()
    {
        boolean convertFlag = true;
        String xml = new String();
        xml = XmlLib.AddToXml(xml, "<pronEntry>", 2); 
        xml = XmlLib.AddToXml(xml, "<variants>", "</variants>", 
            variants_, 3, convertFlag);
        xml = XmlLib.AddToXml(xml, "<type>", "</type>", type_, 3, convertFlag);
        if(gender_ != null)
        {
            String genderTag = "<gender type=\"" + gender_ + "\"/>";
            xml = XmlLib.AddToXml(xml, genderTag, 3);
        }
        xml = XmlLib.AddToXml(xml, "<interrogative/>", interrogative_, 3);
        xml = XmlLib.AddToXml(xml, "</pronEntry>", 2); 
        return xml;
    }
    // data member
    private Vector<String> variants_ = new Vector<String>();
    private String gender_ = null;
    private boolean interrogative_ = false;
    private Vector<String> type_ = new Vector<String>();
}
