package gov.nih.nlm.nls.lexCheck.Lib;
import java.util.*;
/*****************************************************************************
* This class provides a Java object for editing a text LexRecord.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class TextLib
{
    /**
    *    Creates a default lexical record object
    */
    public TextLib()
    {
    }
    // static methods
    /**
    * Add a collection of fillers to a lexical record
    *
    * @param  orgText   the original text
    * @param  slot      the slot of the filler 
    * @param  fillers   a collectionof fillers
    * @param  numIndent   number of indent
    *
    * @return the text after all fillers are added
    */
    public static String AddToText(String orgText, String slot, 
        Vector<String> fillers, int numIndent)
    {
        if(fillers == null)
        {
            return orgText;
        }
        String out = orgText;
        for(int i = 0; i < fillers.size(); i++)
        {
            out += (GetIndent(numIndent) + slot + fillers.elementAt(i) 
                + LS);
        }
        return out;
    }
    /**
    * Add a filler to a lexical record
    *
    * @param  orgText   the original text
    * @param  slot      the slot of the filler 
    * @param  filler    a filler to be added
    * @param  numIndent   number of indent
    *
    * @return the text after all fillers are added
    */
    public static String AddToText(String orgText, String slot, 
        String filler, int numIndent)
    {
        String out = orgText;
        if(filler != null)
        {
            out += (GetIndent(numIndent) + ConvertNullToNewStr(slot) 
                + ConvertNullToNewStr(filler) + LS);
        }
        return out;
    }
    /**
    * Add a boolean flag to a lexical record
    *
    * @param  orgText   the original text
    * @param  slot      the slot of the boolean flag 
    * @param  flag      boolean flag
    * @param  numIndent   number of indent
    *
    * @return the text after all fillers are added
    */
    public static String AddToText(String orgText, String slot, 
        boolean flag, int numIndent)
    {
        String out = orgText;
        if(flag == true)
        {
            out += (GetIndent(numIndent) + ConvertNullToNewStr(slot) + LS);
        }
        return out;
    }
    // private methods
    private static String ConvertNullToNewStr(String inStr)
    {
        if(inStr != null)
        {
            return inStr;
        }
        return new String();
    }
    private static String GetIndent(int numIndent)
    {
        String indentStr = new String();
        for(int i = 0; i < numIndent; i ++)
        {
            indentStr += GlobalVars.GetTextIndent();
        }
        return indentStr;
    }
    private final static String LS = GlobalVars.LS_STR;
}
