package gov.nih.nlm.nls.lexCheck.Lib;
import java.util.*;
/*****************************************************************************
* This class provides a Java object for editing Xml content.
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class XmlLib
{
    /**
    *    Creates a default lexical record object
    */
    public XmlLib()
    {
    }
    // static methods
    /**
    * Add a tag to the xml format of a lexical record
    *
    * @param  xml   the original xml
    * @param  tag   the tag to be added
    * @param  numIndent   number of indent
    *
    * @return the xml after tag added 
    */
    public static String AddToXml(String xml, String tag, int numIndent)
    {
        xml += (GetIndent(numIndent) + tag + LS);
        return xml;
    }
    /**
    * Add a tag with a boolean flag to the xml format of a lexical record
    *
    * @param  xml   the original xml
    * @param  tag   the tag of the boolean flag to be added
    * @param  flag  the boolean flag to be added
    * @param  numIndent   number of indent
    *
    * @return the xml after tag with boolean flag added 
    */
    public static String AddToXml(String xml, String tag, boolean flag,
         int numIndent)
    {
        if(flag == true)
        {
            xml += (GetIndent(numIndent) + tag + LS);
        }
        return xml;
    }
    /**
    * Add a value with a staring and ending tags to the xml format of a 
    * lexical record
    *
    * @param  xml   the original xml
    * @param  startTag  the start tag for the value
    * @param  endTag    the end tag for the value
    * @param  value     the value to be added
    * @param  numIndent   number of indent
    * @param  convertFlag  flag for converting to numericEntity
    *
    * @return the xml after value with start and end tag added 
    */
    public static String AddToXml(String xml, String startTag, String endTag, 
        String value, int numIndent, boolean convertFlag)
    {
        if(value != null)
        {
            String tempValue = value.trim();
            if(convertFlag == true)
            {
                tempValue = Convert.ToNumericEntity(value);
            }
            xml += (GetIndent(numIndent) + startTag + tempValue + endTag + LS);
        }
        return xml;
    }
    /**
    * Add a collection of values with staring and ending tags to the xml 
    * format of a lexical record
    *
    * @param  xml   the original xml
    * @param  startTag  the start tag for the values
    * @param  endTag    the end tag for the values
    * @param  values    the collection of values to be added
    * @param  numIndent   number of indent
    * @param  convertFlag  flag for converting to numericEntity
    *
    * @return the xml after values with start and end tags added 
    */
    public static String AddToXml(String xml, String startTag, String endTag, 
        Vector<String> values, int numIndent, boolean convertFlag)
    {
        if(values == null)
        {
            return xml;
        }
        for(int i = 0; i < values.size(); i++)
        {
            String value = values.elementAt(i).trim();
            if(convertFlag == true)
            {
                value = Convert.ToNumericEntity(value);
            }
        
            xml += (GetIndent(numIndent) + startTag + value + endTag + LS);
        }
        return xml;
    }
    private static String GetIndent(int numIndent)
    {
        String indentStr = new String();
        for(int i = 0; i < numIndent; i++)
        {
            indentStr += GlobalVars.GetXmlIndent();
        }
        return indentStr;
    }
    // data member
    private final static String LS = GlobalVars.LS_STR;
}
