package gov.nih.nlm.nls.lexCheck.Tools;
import java.util.*;
import java.io.*;
import java.nio.file.*;
import java.nio.charset.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.Gram.*;
import gov.nih.nlm.nls.lexCheck.Api.*;
import gov.nih.nlm.nls.lvg.Lib.*;
/*****************************************************************************
* This class provides a command line program for generating inflected 
* variants from a lexical record (text) read in from a file.
*
* <p><b>History:</b>
* <ul>
* <li>SCR-51, chlu, 12-10-15, build with java 1.8
* </ul>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class GenerateInflVars
{
    // public method
    /**
    * command line program for generating inflected variants from
    * a input file.
	*
	* @param  args  input arguments
    */
    public static void main(String[] args)
    {
		// from optin String if there are arguments
		String inFile = "LEXICON";
		String outFile = "inflVars.data";

        if(args.length == 2)
        {
			inFile = args[0];
			outFile = args[1];
		}
		else if(args.length > 0)
		{
            System.out.println("** Usage: java GenerateInflVars <inFile> <outFile>");
            System.exit(0);
        }

		System.out.println("-- inFile: [" + inFile + "]");
		System.out.println("-- outFile: [" + outFile + "]");
		try
		{
			// Go through LexCheck
			Vector<InflVar> inflVars 
				= ToInflVarsApi.GetInflVarsFromTextFile(inFile);
			InflVarComparator<InflVar> comp = new InflVarComparator<InflVar>();
			Collections.sort(inflVars, comp);

			BufferedWriter outWriter = Files.newBufferedWriter(
				Paths.get(outFile), Charset.forName("UTF-8"));

			// print out result
			for(int i = 0; i < inflVars.size(); i++)
			{
				InflVar inflVar = inflVars.elementAt(i);
				if(inflVar.GetUnique() == true)
				{
					String outStr = inflVar.GetVar() + "|" 
						+ Category.ToValue(inflVar.GetCat()) + "|"
						+ Inflection.ToValue(inflVar.GetInflection()) + "|"
						+ inflVar.GetEui() + "|"
						+ inflVar.GetUnInfl() + "|"
						+ inflVar.GetCit();
					outWriter.write(outStr);
					outWriter.newLine();
				}
			}

			// close
			outWriter.close();
		}
		catch(Exception x)
		{
			System.out.println("** ERR@GenerateInflVars( ): " + x.toString());
		}
    }
}
