package gov.nih.nlm.nls.lexCheck.Tools;
import com.ibm.xml.parser.Parser;
import java.io.*;
import java.util.*;
import gov.nih.nlm.nls.lexCheck.Api.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lexCheck.CheckCont.*;
/*****************************************************************************
* This class provides a command line program for Lexicon cross check.
* It cross checks lexRecord, EUIs, and cross-ref EUIs.
*
* <p><b>History:</b>
* <ul>
* <li>SCR-51, chlu, 12-10-15, build with java 1.8
* </ul>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class LexCrossCheck
{
    /**
    * command line program for validating lexical records' base and 
    * spelling variatns with variants setting (glreg and regd)
    * by reading a Text foramt from a input file.
	*
	* @param  args  input arguments
    */
    static public void main(String[] args)
    {
        String inFile = "LEXICON";
        String autoFixFile = "LEXICON.fix";
        boolean verbose = false;
        String prepositionFile = "../data/Files/prepositions.data";
        String dupRecExpFile = "../data/Files/dupRecExceptions.data";
        String notBaseFormFile = "../data/Files/notBaseForm.data";

        if(args.length == 6)
        {
            inFile = args[0];
            autoFixFile = args[1];
            if(args[2].equals("-v") == true)
            {
                verbose = true;
            }
            prepositionFile = args[3];
            dupRecExpFile = args[4];
            notBaseFormFile = args[5];
        }
        else if(args.length == 3)
        {
            inFile = args[0];
            autoFixFile = args[1];
            if(args[2].equals("-v") == true)
            {
                verbose = true;
            }
        }
        else if(args.length == 2)
        {
            inFile = args[0];
            autoFixFile = args[1];
        }
        else if(args.length == 1)
        {
            inFile = args[0];
            autoFixFile = inFile + ".fix";
        }
        else if(args.length >= 0)
        {
            System.err.println("** Usage: java LexCrossCheck <inFile> <outFile> <-v> <prepositionFile> <dupRecExpFile> <notBaseFormFile>");
            System.err.println("");
            System.err.println("Options:");
            System.err.println("  inFile: LEXICON in text format");
            System.err.println("  outFile: auto-fixed LEXICON in text format");
            System.err.println("  -v: verbose");
            System.err.println("  prepositionFile: preposition file");
            System.err.println("  dupRecExpFile: dup record exception file");
            System.err.println("  notBaseFormFile: not base form file");
            System.exit(1);
        }
        
        // verbose
        if(verbose == true)
        {
            System.out.println("===== LexCrossCheck( ) =====");
            System.out.println("-- inFile: " + inFile);
            System.out.println("-- autoFixFile: " + autoFixFile);
            System.out.println("-- prepositionFile: " + prepositionFile);
            System.out.println("-- dupRecExpFile: " + dupRecExpFile);
            System.out.println("-- notBaseFormFile: " + notBaseFormFile);
        }
        // set up preposition
        GlobalVars.SetPrepositionFile(prepositionFile);
        // read in dupExplist
        int lineNum = 500;
        Hashtable<String, HashSet<String>> dupRecExpList
            = KeyValuesTable.GetKey2ValuesTable(dupRecExpFile, verbose, 
            lineNum);
        // read in notBaseFormSet
        boolean useDefaultFileFlag = false; 
        HashSet<String> notBaseFormSet
            = SetTable.GetSetTabe(notBaseFormFile, verbose, lineNum,
            useDefaultFileFlag);
        
        // check contents from a inFile LEXICON
        CrossCheckLexRecords.CheckFromFile(inFile, autoFixFile, verbose, 
            dupRecExpList, notBaseFormSet);
    }
}
