package gov.nih.nlm.nls.lexCheck.Tools;
import com.ibm.xml.parser.Parser;
import java.io.FileInputStream;
import java.io.InputStream;
import java.util.Hashtable;
import org.w3c.dom.*;
import java.util.*;
import gov.nih.nlm.nls.lexCheck.Api.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lvg.Lib.*;
/*****************************************************************************
* This class provides a command line program for generating java object of 
* a lexical record which reads in it's Text format from a file.
*
* <p><b>History:</b>
* <ul>
* <li>SCR-51, chlu, 12-10-15, build with java 1.8
* </ul>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class ToJavaObjectFromTextFile
{
    /**
    * command line program for generating java object of a lexical record 
    * by reading a Text foramt from a input file.
	*
	* @param  args  input arguments
    */
    static public void main(String[] args)
    {
        if((args.length == 0) || (args.length > 2))
        {
            System.err.println("** Usage: java ToJavaObjectFromTextFile <inFile(Text)> <-i>");
			System.err.println("");
			System.err.println("Options:");
			System.err.println(" -i: generate inflection vars");
            System.exit(1);
        }
        boolean inflVarFlag = false;
        for(int i = 0; i < args.length; i++)
        {
            if(args[i].equals("-i"))    // infl vars
            {
                inflVarFlag = true;
                break;
            }
        }
        try
        {
            Vector<LexRecord> lexRecords 
                = ToJavaObjApi.ToJavaObjsFromTextFile(args[0]);
            if(lexRecords.size() <= 0)
            {
                System.exit(1);
            }
            else
            {
                // print out lexRecords
                for(int i = 0; i < lexRecords.size(); i++)
                {
                    LexRecord lexRecord = lexRecords.elementAt(i);
                    System.out.print(lexRecord.GetText());
                    // print out inflVars
                    if(inflVarFlag == true)
                    {
                        System.out.println("----- Inflection Vars -----");
                        Vector<InflVar> inflVars = 
                        lexRecord.GetInflVarsAndAgreements().GetInflValues();
                        for(int j = 0; j < inflVars.size(); j++)
                        {
                            InflVar inflVar = inflVars.elementAt(j);
                            System.out.println(inflVar.GetVar() + "|"
                                + Category.ToValue(inflVar.GetCat()) + "|"
                                + Inflection.ToValue(inflVar.GetInflection()) 
                                + "|"
                                + inflVar.GetEui() + "|"
                                + inflVar.GetUnInfl() + "|"
                                + inflVar.GetCit());
                        }
                    }
                }
            }
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }
    }
}
