package gov.nih.nlm.nls.lexCheck.Tools;
import com.ibm.xml.parser.Parser;
import java.io.*;
import java.util.Hashtable;
import org.w3c.dom.*;
import java.util.*;
import gov.nih.nlm.nls.lexCheck.Api.*;
import gov.nih.nlm.nls.lexCheck.Lib.*;
import gov.nih.nlm.nls.lvg.Lib.*;
/*****************************************************************************
* This class provides a command line program for validating text syntax of 
* a lexical record froma text file. Inputs include:
* <ul>
* <li>inFile
* <li>verbose flag: -v
* <li>prepositions.data
* </ul>
*
* <p><b>History:</b>
*
* @author NLM Lexical System Development Team
*
* @version    V-2016
****************************************************************************/
public class ValidateSyntaxFromTextFile
{
    /**
    * command line program for generating java object of a lexical record 
    * by reading a Xml foramt from a input file.
	*
	* @param  args  input arguments
    */
    static public void main(String[] args)
    {
        String inFile = "LEXICON";
        String prepositionFile = "../data/Files/prepositions.data";
        boolean verbose = false;
        if(args.length == 1)
        {
            inFile = args[0];
        }
        else if(args.length == 2)
        {
            inFile = args[0];
            if(args[1].equals("-v") == true)
            {
                verbose=true;
            }
        }
        else if(args.length == 3)
        {
            inFile = args[0];
            if(args[1].equals("-v") == true)
            {
                verbose=true;
            }
            prepositionFile = args[2];
        }
        else if(args.length >= 0)
        {
            System.err.println("** Usage: java ValidateSyntaxFromTextFile <inFile> <verbose> <prepositionFile>");
            System.exit(1);
        }
        // use ToJavaObjApi to check syntax
        int recNum = 0;
        try
        {
            recNum = ToJavaObjApi.CheckRecordsFromTextFile(inFile, 
                prepositionFile);
        }
        catch (Exception e)
        {
            e.printStackTrace();
        }
        // verbose
        if(verbose == true)
        {
            System.out.println("===== ValidateSyntaxFromTextFile( ) ======");
            System.out.println("-- inFile: [" + inFile + "]");
            System.out.println("-- prepositionsFile: [" 
                + GlobalVars.GetPrepositionFile() + "]");
        }
        // final printout
        // if there is a error, the msg will show up before here
        if(recNum > 0)
        {
            System.out.println("-- inFile(" + inFile + "): " + recNum 
                + " records checked. No error found.");
        }
    }
}
